# coding: utf-8

"""
    aind-metadata-service

     ## aind-metadata-service  Service to pull data from example backend.  

    The version of the OpenAPI document: 1.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_metadata_service_client.models.anyof_schema1_validator import AnyofSchema1Validator

class TestAnyofSchema1Validator(unittest.TestCase):
    """AnyofSchema1Validator unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnyofSchema1Validator:
        """Test AnyofSchema1Validator
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnyofSchema1Validator`
        """
        model = AnyofSchema1Validator()
        if include_optional:
            return AnyofSchema1Validator(
            )
        else:
            return AnyofSchema1Validator(
        )
        """

    def testAnyofSchema1Validator(self):
        """Test AnyofSchema1Validator"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
