# coding: utf-8

"""
    aind-metadata-service

     ## aind-metadata-service  Service to pull data from example backend.  

    The version of the OpenAPI document: 1.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SlimsWorkflow(str, Enum):
    """
    Available workflows that can be queried.
    """

    """
    allowed enum values
    """
    SMARTSPIM_IMAGING = 'smartspim_imaging'
    HISTOLOGY = 'histology'
    WATER_RESTRICTION = 'water_restriction'
    VIRAL_INJECTIONS = 'viral_injections'
    ECEPHYS_SESSIONS = 'ecephys_sessions'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SlimsWorkflow from a JSON string"""
        return cls(json.loads(json_str))


