# coding: utf-8

"""
    aind-metadata-service

     ## aind-metadata-service  Service to pull data from example backend.  

    The version of the OpenAPI document: 1.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_metadata_service_client.models.slims_workflow import SlimsWorkflow

class TestSlimsWorkflow(unittest.TestCase):
    """SlimsWorkflow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSlimsWorkflow(self):
        """Test SlimsWorkflow"""
        # inst = SlimsWorkflow()

if __name__ == '__main__':
    unittest.main()
